"""
Tests for `segment` module.
"""
import pytest
from segment import segment


class TestSegment(object):

    @classmethod
    def setup_class(cls):
        pass

    def test_something(self):
        pass

    @classmethod
    def teardown_class(cls):
        pass
